@@ -107,7 +107,7 @@ class Solvent(Molecule):
         zeta = y3m / y3
         return zeta
 
-    def to_file(self,filename):
+    def to_smdl_file(self,filename, structure_factor):
         with open(filename,"w") as fp:
             fp.write("<geometry>\n")
             fp.write("# site   type   x     y     z\n")
@@ -125,15 +125,20 @@ class Solvent(Molecule):
             fp.write(F"temp {self.temp}\n")
             fp.write(F"dielectric {self.dielectric}\n")
 
-            if self.s_k is not None:
-                fp.write("<s_k>\n")
-                fp.write(F"{self.nv}   {self.ifft.ngrid}\n")
-                for k in range(self.ifft.ngrid):
-                    fp.write(F"{self.kgrid[k]}   ")
-                    for i in range(self.nv):
-                        for j in range(i, self.nv):
-                            fp.write(F"{self.s_k[i,j,k]}  ")
-                    fp.write("\n")
+            s_k = structure_factor["s_k"]
+            kgrid  = structure_factor["kgrid"]
+            tag = structure_factor["tag"]
+            ngrid = s_k.shape[-1]
+            nv = s_k.shape[0]
+
+            fp.write(F"<{tag}>\n")
+            fp.write(F"{nv}   {ngrid}\n")
+            for k in range(ngrid):
+                fp.write(F"{kgrid[k]}   ")
+                for i in range(nv):
+                    for j in range(i, nv):
+                        fp.write(F"{s_k[i,j,k]}  ")
+                fp.write("\n")
 def solvent_model_locate(solvent_name):
     solvent = solvent_name + ".smdl"
     cwd = pathlib.Path.cwd()
@@ -184,6 +189,11 @@ if __name__ == "__main__":
     geom = read_geom("../data/s2.smdl")
     params = dict(density=1.0)
     # solvent = Solvent(**params,**geom)
-    solvent = Solvent.from_file("../data/s2.smdl")
+    solvent = Solvent.from_file("../data/s2.smdl", rism_patch=True)
 
-    solvent.to_file("test.dat")
+    structure_factor = dict (
+        tag="s_k",
+        kgrid = solvent.ifft.kgrid,
+        s_k = solvent.s_k
+    )
+    solvent.to_smdl_file("test1.dat", structure_factor)
