@@ -182,6 +182,70 @@ def bst_inverse(rg, kg, fk):
     return fr
 
 
+class RadArray():
+    """
+    Provides FFT operations for spherically symmetric functions
+
+    Args:
+        dr:    grid spacing
+        ngrid:  number of grid points
+
+    """
+
+    def __init__(self, shape, ifft):
+
+        dims = list(shape,)
+        dims.append(ifft.ngrid)
+        self.r = np.zeros(dims)
+
+    @classmethod
+    def from_rgrid(cls, rg):
+        ntot = len(rg)
+        dr = rg[1] - rg[0]
+
+        return RadFFT(dr, ntot)
+
+    @classmethod
+    def from_kgrid(cls, kg):
+        ntot = len(kg)
+        dk = kg[1] - kg[0]
+
+        dr = fft_rgrid_spacing(dk,ntot)
+
+        return RadFFT(dr, ntot)
+
+    def to_kspace(self, fr):
+        """
+        Generates k-space representation
+
+        Args:
+            fr: function on a radial grid
+
+        Returns:
+            k-space representation of fr
+
+        """
+        fk = bst_forward(self.rgrid, self.kgrid, fr)
+        return fk
+
+    def to_rspace(self, fk):
+        """
+        Generates r-space representation
+
+        Args:
+            fk: function on a reciprocal grid
+
+        Returns:
+            r-space representation of fr
+
+        """
+        fr = bst_inverse(self.rgrid, self.kgrid, fk)
+        return fr
+
+    def integrate_rspace(self, fr):
+        frr = np.einsum('an,n->a', fr, self.rgrid ** 2)
+        return 4.0 * np.pi * self.dr * np.sum(frr)
+
 class RadFFT:
     """
     Provides FFT operations for spherically symmetric functions
@@ -275,4 +339,10 @@ if __name__ == '__main__':
     # fk = ifft.to_kspace(fr)/math.sqrt(2*ngrid)
 
     print(fr0[0],fr[0],fr0[0]-fr[0])
+
+    h = RadArray((2,2), ifft)
+    print(h.r.shape)
+    h.r = 0
+    print(h.r)
+
     pass
\ No newline at end of file
